"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStateValue = exports.getStatePositionForAny = exports.getStatePositionForAbsolute = exports.getStatePositionAnchorAbsolute = exports.getStatePositionAnchor = exports.getStatePositionAbsoluteForLineColumn = exports.getStatePositionAbsolute = exports.getStatePosition = exports.getStateLineObjectForLine = exports.getStateLineObjectForAbsolute = exports.getStateLineCount = exports.getStateLength = exports.getStateHasSelection = exports.getStateEditorSupport = void 0;
var _cypherCodemirrorBase = require("./cypher-codemirror-base");
var _cypherStateDefinitions = require("./cypher-state-definitions");
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

const getStatePositionAnchorAbsolute = state => state.selection.main.anchor;
exports.getStatePositionAnchorAbsolute = getStatePositionAnchorAbsolute;
const getStatePositionAbsolute = state => state.selection.main.head;
exports.getStatePositionAbsolute = getStatePositionAbsolute;
const getStateEditorSupport = state => state.field(_cypherStateDefinitions.editorSupportField, false);
exports.getStateEditorSupport = getStateEditorSupport;
const getStateLineCount = state => state.doc.lines;
exports.getStateLineCount = getStateLineCount;
const getStateValue = state => state.doc.toString();
exports.getStateValue = getStateValue;
const getStateLength = state => state.doc.length;
exports.getStateLength = getStateLength;
const getStateLineObjectForLine = (state, line) => state.doc.line(line);
exports.getStateLineObjectForLine = getStateLineObjectForLine;
const getStateLineObjectForAbsolute = (state, position) => state.doc.lineAt(position);
exports.getStateLineObjectForAbsolute = getStateLineObjectForAbsolute;
const getStatePositionAbsoluteForLineColumn = (state, {
  line,
  column
}) => state.doc.line(line).from + column;
exports.getStatePositionAbsoluteForLineColumn = getStatePositionAbsoluteForLineColumn;
const getStatePositionForAbsolute = (state, position) => {
  const {
    number: line,
    from: lineStart
  } = getStateLineObjectForAbsolute(state, position);
  const column = position - lineStart;
  return {
    line,
    column,
    position
  };
};
exports.getStatePositionForAbsolute = getStatePositionForAbsolute;
const getStatePosition = state => getStatePositionForAbsolute(state, getStatePositionAbsolute(state));
exports.getStatePosition = getStatePosition;
const getStatePositionAnchor = state => getStatePositionForAbsolute(state, getStatePositionAnchorAbsolute(state));
exports.getStatePositionAnchor = getStatePositionAnchor;
const getStatePositionForAny = (state, positionValue) => {
  let position = null;
  if ((0, _cypherCodemirrorBase.isAbsolutePosition)(positionValue)) {
    position = positionValue;
  } else if ((0, _cypherCodemirrorBase.isLineColumnAbsolutePosition)(positionValue)) {
    position = positionValue.position;
  } else if ((0, _cypherCodemirrorBase.isLineColumnPosition)(positionValue)) {
    const {
      line,
      column
    } = positionValue;
    const lineCount = getStateLineCount(state);
    if (line <= lineCount) {
      const lineObject = getStateLineObjectForLine(state, line);
      if (lineObject) {
        const {
          from,
          to
        } = lineObject;
        if ((0, _cypherCodemirrorBase.isInteger)(from) && (0, _cypherCodemirrorBase.isInteger)(to) && column <= to - from) {
          position = from + column;
        }
      }
    }
  }
  if (position !== null) {
    if (position <= getStateLength(state)) {
      const lineObject = getStateLineObjectForAbsolute(state, position);
      if (lineObject) {
        const {
          number: line,
          from: lineStart,
          to: lineEnd
        } = lineObject;
        const column = position - lineStart;
        if (lineStart + column <= lineEnd) {
          position = {
            line,
            column,
            position
          };
        } else {
          position = null;
        }
      } else {
        position = null;
      }
    } else {
      position = null;
    }
  }
  return position;
};
exports.getStatePositionForAny = getStatePositionForAny;
const getStateHasSelection = state => state.selection.ranges.some(r => !r.empty);
exports.getStateHasSelection = getStateHasSelection;